import React from 'react';

import { useSelector } from 'react-redux';
import { geoPoint, lat2tile, lon2tile, Point } from '../../lib/geo';

import { MapState } from '../../store/map';
import { tileProviders } from './tile';

interface AvatarForLocationProps {
  location: geoPoint;
  zoom?: number;
  tileProvider?: string;
  size?: number;
  name?: string;
}

const AvatarForLocation: React.FC<AvatarForLocationProps> = (
  props: AvatarForLocationProps
) => {
  const size = props.size ? props.size : 42;
  const zoom = props.zoom ? Math.round(props.zoom) : 16;
  const tileProvider = props.tileProvider ? props.tileProvider : 'osm';
  const location = props.location;
  const name = props.name ? props.name : '???';

  const tilesLocation: Point = {
    x: lon2tile(location.lon, zoom),
    y: lat2tile(location.lat, zoom),
  };


  return (
    <svg width={size} height={size}>
      <defs>
        <clipPath id='cut-off'>
          <circle cx={size / 2} cy={size / 2} r={size / 2} />
        </clipPath>
      </defs>
      <g clip-path='url(#cut-off)'>
        <image href={tileProviders[tileProvider].getTileUrl(zoom, Math.floor(tilesLocation.x), Math.floor(tilesLocation.y))} />
        <text x='2' y={size / 2 + 5}>
          {name}
        </text>
      </g>
    </svg>
  );
};

export default AvatarForLocation;
